@@ -22,6 +22,7 @@ tests = testGroup "Language.Haskell.Stylish.Parse"
     , testCase "Haskell2010 extension"       testHaskell2010
     , testCase "Shebang"                     testShebang
     , testCase "ShebangExt"                  testShebangExt
+    , testCase "ShebangDouble"               testShebangDouble
     , testCase "GADTs extension"             testGADTs
     , testCase "KindSignatures extension"    testKindSignatures
     , testCase "StandalonDeriving extension" testStandaloneDeriving
@@ -85,6 +86,16 @@ testShebang = assert $ isRight $ parseModule [] Nothing $ unlines
 
 --------------------------------------------------------------------------------
 
+testShebangDouble :: Assertion
+testShebangDouble = assert $ isRight $ parseModule [] Nothing $ unlines
+    [ "#!nix-shell"
+    , "#!nix-shell -i runhaskell -p haskellPackages.ghc"
+    , "module Main where"
+    , "main = return ()"
+    ]
+
+--------------------------------------------------------------------------------
+
 -- | These tests are for syntactic language extensions that should always be
 -- enabled for parsing, even when the pragma is absent.
 
